/* $Id: dri_drv.h $ */

/** @file
 *
 * VirtualBox guest OpenGL DRI header
 */

/*
 * Copyright (C) 2009-2019 Oracle Corporation
 *
 * This file is part of VirtualBox Open Source Edition (OSE), as
 * available from http://www.virtualbox.org. This file is free software;
 * you can redistribute it and/or modify it under the terms of the GNU
 * General Public License (GPL) as published by the Free Software
 * Foundation, in version 2 as it comes in the "COPYING" file of the
 * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
 */

#ifndef GA_INCLUDED_SRC_common_crOpenGL_dri_drv_h
#define GA_INCLUDED_SRC_common_crOpenGL_dri_drv_h
#ifndef RT_WITHOUT_PRAGMA_ONCE
# pragma once
#endif

#include "src/mesa/main/mtypes.h"
#include "src/mesa/drivers/dri/common/dri_util.h"
#include "src/mesa/glapi/dispatch.h"
#include "src/mesa/main/dd.h"

#endif /* !GA_INCLUDED_SRC_common_crOpenGL_dri_drv_h */

